<?php
/**
*
* @package Board3 Portal v2 - Download Block
* @copyright (c) phpBB-Projekt ( www.phpbb-projekt.de )
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* @package Download Block
*/
class portal_download_side_module
{
	/**
	* Allowed columns: Just sum up your options (Exp: left + right = 10)
	* top		1
	* left		2
	* center	4
	* right		8
	* bottom	16
	*/
	var $columns = 10;

	/**
	* Default modulename
	*/
	var $name = 'PORTAL_DOWNLOAD';

	/**
	* Default module-image:
	* file must be in "{T_THEME_PATH}/images/portal/"
	*/
	var $image_src = 'portal_download.png';

	/**
	* module-language file
	* file must be in "language/{$user->lang}/mods/portal/"
	*/
	var $language = 'portal_download_module';
	
	/**
	* custom acp template
	* file must be in "adm/style/portal/"
	*/
	var $custom_acp_tpl = '';

	function get_template_side($module_id)
	{
		global $config, $db, $user, $auth, $template, $cache, $dl_cache;
		global $phpbb_root_path, $phpEx, $table_prefix;

		$user->data['dl_enable_desc'] = false;
		$user->data['dl_enable_rule'] = false;

		if (!class_exists('dlmod'))
		{
			include($phpbb_root_path . 'dl_mod/classes/class_dl_cache.' . $phpEx);
			include($phpbb_root_path . 'dl_mod/classes/class_dlmod.' . $phpEx);
		}

		$sql = 'SELECT d.*, c.cat_name, c.auth_view, c.auth_dl 
			FROM ' . DOWNLOADS_TABLE . '  d,
				' . DL_CAT_TABLE . ' c
			WHERE c.id = d.cat
				AND d.approve = 1
				AND d.broken = 0
			ORDER BY d.change_time DESC';

		if ($config['board3_max_dl_' . $module_id] <> 0)
		{
     		$result = $db->sql_query_limit($sql, $config['board3_max_dl_' . $module_id]);
		} 
        else
        {
			$result = $db->sql_query($sql);
		}

		while($row = $db->sql_fetchrow($result))
		{
			$cat = $row['cat'];
			$cat_auth = array();
			$cat_auth = $dl_mod->dl_cat_auth($cat);

			if ($cat_auth['auth_dl'] || $row['auth_dl'] || ($auth->acl_get('a_') && $user->data['is_registered']))
			{
				$template->assign_block_vars('recent_dl', array(
					'TITLE'	 		=> character_limit($row['description'], $config['board3_dl_title_limit_' . $module_id]),
					'FULL_TITLE'	=> censor_text($row['description']),
					'CAT_NAME' 		=> $row['cat_name'],
					'U_CAT_LINK' 	=> ($cat_auth['auth_view'] || $row['auth_view']) ? append_sid("{$phpbb_root_path}downloads.$phpEx", 'cat=' . $row['cat']) : '',
					'MINI_IMG' 		=> $dl_mod->mini_status_file($row['cat'], $row['id']),
					'U_DL_DETAIL'	=> append_sid("{$phpbb_root_path}downloads.$phpEx", 'view=detail&amp;df_id=' . $row['id'])
				));
			}
		}
		$db->sql_freeresult($result);

		$template->assign_vars(array(
			'S_DISPLAY_RECENT_DL'	=> true)
		);
	
		return 'download_side.html';
	}

	function get_template_acp($module_id)
	{
		global $phpbb_root_path, $phpEx, $user, $db;

		$portal_modules = obtain_portal_modules();
		$side_column = false;

		foreach ($portal_modules as $cur_module)
		{
			if ($cur_module['module_id'] == $module_id)
			{
				$cur_column = column_num_string($cur_module['module_column']);

				if (in_array($cur_column, array('left', 'right')))
				{
					$side_column = true;
				}
			}
		}

		return array(
			'title'	=> 'ACP_PORTAL_DOWNLOAD_SETTINGS',
			'vars'	=> array(
				'legend1'                               => 'ACP_PORTAL_DOWNLOAD_SETTINGS_SIDE',
				'board3_dl_title_limit_' . $module_id   => array('lang' => 'PORTAL_DL_TITLE_LIMIT',		'validate' => 'int',	'type' => 'text:7:3',		'explain' => true),
				'board3_max_dl_' . $module_id           => array('lang' => 'PORTAL_MAX_DL',	'validate' => 'int',	'type' => 'text:7:3',		'explain' => true),
			),
		);
	}

	/**
	* API functions
	*/
	public function install($module_id)
	{
		set_config('board3_dl_title_limit_' . $module_id, 100);
		set_config('board3_max_dl_' . $module_id, 3);

		return true;
	}

	public function uninstall($module_id)
	{
		global $db;

		$del_config = array(
			'board3_dl_title_limit_' . $module_id,
			'board3_max_dl_' . $module_id,
		);

		$sql = 'DELETE FROM ' . CONFIG_TABLE . '
			WHERE ' . $db->sql_in_set('config_name', $del_config);
		return $db->sql_query($sql);
	}
}

?>